<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Odaberi jedan ili više uređaja</translation>
    </message>
</context>
<context>
    <name>QvkAudioController_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Odaberi jedan ili više uređaja</translation>
    </message>
</context>
<context>
    <name>QvkCameraSingle</name>
    <message>
        <source>Remove window frame</source>
        <translation>Uklonite okvir prozora</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Okrenite okomito </translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Okreni vodoravno</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Izokreni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Crno-bijelo</translation>
    </message>
    <message>
        <source>Switch to Window</source>
        <translation>Prebaci na prozor</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>Prebaci na cijeli zaslon</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
</context>
<context>
    <name>QvkCiscoFinishDialog</name>
    <message>
        <source>The setup was successful.</source>
        <translation>Postavljanje je bilo uspješno.</translation>
    </message>
    <message>
        <source>Close this window and start vokoscreenNG again.</source>
        <translation>Zatvorite ovaj prozor i ponovno pokrenite vokoscreenNG.</translation>
    </message>
    <message>
        <source>Have fun with vokoscreenNG</source>
        <translation>Zabavite se uz vokoscreenNG</translation>
    </message>
</context>
<context>
    <name>QvkDirDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dijalog</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Upravitelj datoteka nije pronađen. 
 </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Molim instalirajte filemanager</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs_wl</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Upravitelj datoteka nije pronađen. 
 </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Molim instalirajte filemanager</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>Snimanje nije pokrenuto, nema dovoljno slobodnog prostora na disku.</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>Dosegnuto je ograničenje slobodnog prostora na disku.</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ograničenje slobodnog prostora na disku</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>Snimanje je zaustavljeno, nema dovoljno slobodnog prostora na disku.</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>No filemanager found.</source>
        <extracomment>Display a MessageBox, if not found a filemanager.</extracomment>
        <translation>Upravitelj datoteka nije pronađen. 
 </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Molim instalirajte filemanager</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>Izvorni kod </translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Početna stranica </translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Prijevodi </translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donirajte</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow_wl</name>
    <message>
        <source>Sourcecode</source>
        <translation>Izvorni kod </translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Početna stranica </translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>Prijevodi </translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donirajte</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>Upravitelj datoteka nije pronađen. 
 </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Molim instalirajte filemanager</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Odaberi jedan ili više uređaja</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher_wl</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Odaberi jedan ili više uređaja</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>Površina</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise_wl</name>
    <message>
        <source>Area</source>
        <translation>Površina</translation>
    </message>
</context>
<context>
    <name>QvkSnapshot</name>
    <message>
        <source>No filemanager found.</source>
        <translation>Upravitelj datoteka nije pronađen. 
 </translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>Molim instalirajte filemanager</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nastavi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izlaz</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povećanje </translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nastavi</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Izlaz</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Povećanje</translation>
    </message>
</context>
<context>
    <name>QvkWASAPIController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>Odaberi jedan ili više uređaja</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dijalog</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Okreni vodoravno</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Okrenite okomito </translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Izokreni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Crno-bijelo</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Uklonite okvir prozora</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>Postavke kamere</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>Površina</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Resetiraj</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>Odbrojavanje</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odbrojavanje </translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Veličina videozapisa: </translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Slobodan prostor na disku: </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacija </translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Vrijeme snimanja: </translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>Audio</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Okviri</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne snimaj kursor miša </translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>Sat</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>Minuta</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>Pokreni tajmer</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>Prekini snimanje nakon</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>Sat</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>Minute</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Skunde</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video-put</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>Ograničenje slobodnog prostora na disku</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>Prikaži u traci sustava </translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Drugo čekanje prije snimanja </translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>Potražite ažuriranja </translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Dostupno</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nije dostupno</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Nastavi</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Izokreni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>Reproduciraj posljednji zapis</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Otvori mapu</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>Minimizirano prilikom pokretanja snimanja</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>Počinje minimizirano</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Okreni vodoravno</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Okrenite okomito </translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Crno-bijelo</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Uklonite okvir prozora</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>Vrati sve postavke na sljedeći početak</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorska prava i licenca sa slika</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>Megabajt</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>Snimke zaslona</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>Izvođač</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>Dnevnik</translation>
    </message>
    <message>
        <source>Automatically</source>
        <translation>Automatski</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Stvorite slike kartica </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Podaci o licenci </translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Ukljućeno</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Isključeno</translation>
    </message>
    <message>
        <source>Global keyboard shortcuts</source>
        <translation>Globalni tipkovnički prečaci </translation>
    </message>
    <message>
        <source>Assigned shortcut keys.</source>
        <translation>Dodijeljene tipke prečaca. </translation>
    </message>
    <message>
        <source>Keyboard shortcut not assigned or assigned more than once.</source>
        <translation>Tipkovni prečac nije dodijeljen ili je dodijeljen više od jednom. </translation>
    </message>
    <message>
        <source>If it shows assigned but does not work, it is being used by another program.</source>
        <translation>Ako se prikazuje kao dodijeljeno, ali ne radi, koristi ga drugi program. </translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Snimak</translation>
    </message>
    <message>
        <source>Imagepath</source>
        <translation>Imagepath</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Sakrij ovaj prozor </translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Sekunde čekanja prije snimanja </translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Prozor</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Puni zaslon </translation>
    </message>
</context>
<context>
    <name>formMainWindow_wl</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorska prava i licenca sa slika</translation>
    </message>
    <message>
        <source>Create images of tabs </source>
        <translation>Stvorite slike kartica </translation>
    </message>
    <message>
        <source>License information</source>
        <translation>Podaci o licenci </translation>
    </message>
    <message>
        <source>ON</source>
        <translation>Ukljućeno</translation>
    </message>
    <message>
        <source>OFF</source>
        <translation>Isključeno</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>Vrijeme snimanja: </translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>Veličina videozapisa: </translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>Slobodan prostor na disku: </translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacija </translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Prozor</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Puni zaslon </translation>
    </message>
    <message>
        <source>Area</source>
        <translation>Površina</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>Videokodek</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>Okviri</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>Dostupno</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>Nije dostupno</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mapa</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>Ne snimaj kursor miša </translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>Audiokodek</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>Video-put</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>Odbrojavanje </translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoć</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>Izokreni</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Sivo</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>Crno-bijelo</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>Okrenite okomito </translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>Okreni vodoravno</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>Uklonite okvir prozora</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>Drugo čekanje prije snimanja </translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>Resetiraj</translation>
    </message>
    <message>
        <source>Hide this window</source>
        <translation>Sakrij ovaj prozor </translation>
    </message>
    <message>
        <source>Seconds wait before recording</source>
        <translation>Sekunde čekanja prije snimanja </translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>Autorska prava i licenca sa slika</translation>
    </message>
</context>
<context>
    <name>playerGST</name>
    <message>
        <source>Play</source>
        <translation>Pokreni</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pauza</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zaustavi</translation>
    </message>
</context>
</TS>